#########################################
Sphinx extensions provided by Documenteer
#########################################

.. toctree::
   :maxdepth: 2

   lssttasks
   autocppapi
   jira-reference
   docushare-reference
   remote-code-block
   package-toctree
   lsst-pybtex-style
